macro_rules! omm_mut {
($integer:ident) => { ... };
}Expand description
Calls overflowing_sub on an integer with 1 as a parameter.
Overwites the provided integer with the first value and returns the tuple.
macro_rules! omm_mut {
($integer:ident) => { ... };
}Calls overflowing_sub on an integer with 1 as a parameter.
Overwites the provided integer with the first value and returns the tuple.