macro_rules! opp {
($integer:ident) => { ... };
}Expand description
Calls overflowing_add on an integer with 1 as a parameter.
Overwites the provided integer with the first value and returns the tuple.
macro_rules! opp {
($integer:ident) => { ... };
}Calls overflowing_add on an integer with 1 as a parameter.
Overwites the provided integer with the first value and returns the tuple.